compute.nv.RdCompute Normal Vector
compute.nv(xmat, resp, nv.method, ...)
| xmat | Matrix of OC coordinates (i.e., predictors). |
|---|---|
| resp | Response Variable (i.e., ordered choices). |
| nv.method | Method of normal vector estimation. Following pre-defined methods are currently available:
Alternatively, one can set custom made function that (at least) feeds in
|
| ... | Additional arguments passed to the function assigned by |
The vector of normal vector estimates.