Compute normal vector from OC coordinates and
ordered responses.
nv.svm(
xmat,
resp,
kernel = "radial",
tune.param = "heuristics",
param.heuristics.k = 3,
param.heuristics.frac = 0.5,
...
)
Arguments
| xmat |
Matrix of OC coordinates (i.e., predictors). |
| resp |
Response Variable (i.e., ordered choices). |
| kernel |
The kernel used in training and predicting. The
default is "radial" to use radial basis function (RBF).
The alterantaives are "linear", "polynomial" or "sigmoid".
See the help file of svm for more details. |
| tune.param |
Method to determine the parameters.
Following options are currently available:
NULL: Use svm with the default
or manually set parameter values. To manually set parameters.
Check the available parameters (and their default values) in
svm function in e1071 package.
"heuristics" (default): If kernel=="radial",
Use heuristics-based method (i.e., formulation identical to
sigest in kernlab package)
to determine optimal gamma. Additionally, if resp is numeric,
use heuristic based method described in Cherkassky & Ma (2004) to
determine optimal parameters for C (cost) and epsilon (epsilon-regression is
automatically selected).
If resp is a factor, the same behavior as NULL.
A named list of parameter vectors spanning the sampling space.
If list is assigned here, the method use best.tune function
to obtain the best perfomed model in the given parameter ranges.
|
| param.heuristics.k |
If tune.param=="heuristics", the method uses
k nearest neighbors regression to estimate the noise variance in response variable
for the detemination of epsilon.
This argument sets k for this method. The default is 3. Cherkassky & Ma (2004)
recommends somewhere between 2 to 6. |
| param.heuristics.frac |
Fraction of data to use for heuristics-based estimation of gamma.
By default, 50 percent of the data is used to estimate the range of the gamma hyperparameter. |
| ... |
Additional arguments passed to svm
or best.tune. |
Value
A vector of coefficients.
References
Chang, C. & C. Lin, LIBSVM: A Library for Support Vector Machines, http://www.csie.ntu.edu.tw/~cjlin/libsvm.
Cherkassky, V. & Y. Ma, 2004, "Practical Selection of SVM Parameters and Noise Estimation for SVM Regression", Neural Networks, 17, 113 - 126.
See also